

*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off


*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"

* Drop Lebanon
drop if peace_id == 124


* Keep information of interest
drop if pgm_presence == .
drop if pgm_warlegacy_count == . & pgm_new_postconf_count == .



*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*-------------------
* Generate the follwing cross-tabs:
*		Termination | Legacy PGM | New  PGM
*		Termination | Semi PGM   | Infor. PGM
*-------------------

* Keep information of interest
	drop if pgm_presence == .

** Generate dummies for semis and informals
	gen pgm_presence_informal_dummy = 0
	replace pgm_presence_informal_dummy = 1 if pgm_presence == 1 & pgm_presence_informal_count!=0

	gen pgm_presence_semi_dummy = 0
	replace pgm_presence_semi_dummy = 1 if pgm_presence == 1 & pgm_presence_semi_count!=0


* Collapse first at the peace_episode level
	#delimit;
	collapse (max) acd_termination_type
				   pgm_presence
				   pgm_warlegacy_dummy
				   pgm_new_postconf_dummy
				   pgm_presence_informal_dummy 
				   pgm_presence_semi_dummy,
			 by(peace_id)
	;
	#delimit cr


* Count how many termination cases 
	gen count = 1


* Keep only cases with PGM presence
*drop if pgm_presence!= 1


* Collapse by termination type
	#delimit;
	collapse (sum) pgm_warlegacy_dummy 
				   pgm_new_postconf_dummy 
				   pgm_presence_informal_dummy 
				   pgm_presence_semi_dummy
				   count,
			 by(acd_termination_type pgm_presence)
	;
	#delimit cr



* Cross tab: Termination | Legacy PGM | New  PGM
* Note (!) % of cases or episodes by termination that have X type of PGM
* Percentages do not add to 100% because some episodes may have both types of PGM
	#delimit ;
	keep  		   acd_termination_type 
				   pgm_warlegacy_dummy 
				   pgm_new_postconf_dummy 
				   pgm_presence_informal_dummy 
				   pgm_presence_semi_dummy
				   count
	;
	#delimit cr


	egen total_within = sum(count), by(acd_termination_type)

** Generate percentages
	gen percent_legacy = (pgm_warlegacy_dummy*100)/total_within
	gen percent_new = (pgm_new_postconf_dummy*100)/total_within

	gen percent_info = (pgm_presence_informal_dummy*100)/count
	gen percent_semi = (pgm_presence_semi_dummy*100)/count


** See percentages
	#delimit ;
	keep  		   acd_termination_type 
				   percent*
				   count
	;
	#delimit cr


*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
