
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off



*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*- Generate peace_id
sort gwno year peace_episode
xtset peace_id year



*- Only for countries we have the complete spell into the sample. 
*- Countries that started post-conflict after 1981 are not included
drop if peace_years>5
*


*- Collapse by spell ID. Use (max) year to identify the most recent post-conflict
*- peace spell if a country has multiple.
collapse (max) gwno year (mean) pts, by(peace_id)





*------------------------------------------------------------------------------*
*- If a country is in the spell data twice, choose the most recent instance of
*- post-conflict peace
*------------------------------------------------------------------------------*

*- Identify the most recent year
	sort gwno peace_id
	*
	gen marker = 0
	replace marker = 1 if gwno[_n]!=gwno[_n+1]
	*
	keep if marker == 1
	*
	drop marker
	*
	
*- Generate a categorical variable for: limites, extensive, widespread
	gen repression = 0
	replace repression = 1 if pts<2.5 // limited
	replace repression = 2 if pts>=2.5 & pts<3.5 //extended
	replace repression = 3 if pts>=3.5 //widespread
	*
	tab repression
	*


*- Save the data
	drop peace_id year pts
	sort gwno
	save "Map/repression.dta", replace



*- Merge with a world data of gwno to have "0" for contries without
*- post conflict peace
	clear
	*
	use "Map/gwno_panel2015.dta"
	*
	gen marker = 1
	*
	collapse (sum) marker, by (gwno)
	*
	replace marker = 1
	sort gwno
	save "Map/gwno.dta", replace
	*

	
*- Now merge
	clear
	use "Map/repression.dta"
	merge 1:1 gwno using "Map/gwno.dta"
	*

	
*- Now assigned no Post-conflict
	replace repression = . if _merge == 2
	*
	drop _merge marker
	* 
	sort gwno
	* 
	save "Map/repression_map.dta", replace






*------------------------------------------------------------------------------*
*- Merge the corss sectional data on PTS (average up to 5 years of post conflict
*- peace) with c-shapes (2014 version) 
*------------------------------------------------------------------------------*

*- Loading cshapes: transforming its information into data sets
	clear
	cd "Map/cshapes"
	shp2dta using cshapes.shp, data(../worlddata) coor(../worldcoor) genid(id) genc(c) replace

	
	
*- Subsetting the years for the polygons 
* Loop for yearly data on Polygons
	cd ..
	use "worlddata.dta",clear
	rename COWCODE ccode

	
	
* Repeated values of ccode - sorting them out
	sort ccode COWSYEAR
	browse if ccode[_n]==ccode[_n-1] & COWSYEAR[_n]==COWSYEAR[_n-1]
	browse if ccode == 345 // Yugoslavia 1946
	drop if id == 226
	browse if ccode == 432 // Mali
	drop if id == 210
	browse if ccode[_n]==ccode[_n-1] & COWEYEAR[_n]==COWEYEAR[_n-1]
	browse if ccode == 365 // Russia 1991
	drop if id == 228

	sort ccode COWEYEAR
	browse if ccode[_n]==ccode[_n+1] & COWSYEAR[_n]==COWSYEAR[_n+1]
	browse if ccode[_n]==ccode[_n+1] & COWEYEAR[_n]==COWEYEAR[_n+1]


save worlddatab.dta, replace

	forval i=2010/2011 {
		preserve
		drop if COWSYEAR>`i' | COWEYEAR<`i'
		save "worlddatab_`i'.dta", replace
		restore
	}	



*- Preparing PTS data and merging-----------------------------------------------
	clear
	* 
	use "repression_map.dta"
	rename gwno ccode
	*
	merge 1:m ccode using worlddatab_2011.dta
	*
	tab repression
	
	
*- Plot the map ----------------------------------------------------------------
	#delimit ;
		spmap repression using worldcoor.dta, id(id) 
		clmethod(unique) 
		fcolor(Reds)
		title("Trail", col(white) size(tiny))
		ytitle("") ylabel(none) xtitle("") xlabel(none)
		xsize(4) ysize(2)
		plotregion(margin(zero))
		graphregion(margin(zero))
		ndlabel("No post-conflict")
		legtitle("Post-conflict""physical repression") 
		legorder(hilo)
		legend(
			   label(2 "Limited") 
			   label(3 "Extended") 
			   label(4 "Widespread")
			   symy(*1) symx(*1) size(*1) 
			   ring(0) position(7)
		)
		;
	#delimit cr
*
graph export "../Figures/cg_repression_map.pdf", replace as(pdf)

*-------------------------------------------------------------------------------
* End of do file
*-------------------------------------------------------------------------------
