
*------------------------------------------------------------------------------*
* DATA PREPARATION
*------------------------------------------------------------------------------*

*-------------------
* Prepare working space
*-------------------
clear	all
set		more off




*-------------------
* Opend dataset 
*-------------------
use 	"Data/cg_postconflict_data_with_rebelvictories.dta"


*-------------------
* Sort data
*-------------------
sort	gwno year
tsset	gwno year



*------------------------------------------------------------------------------*
* MODELS PGM
*------------------------------------------------------------------------------*



*------------------------------------------------------------------------------*
* Model A
*------------------------------------------------------------------------------*

version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5, cl(gwno)
;
#delimit cr
estimates store modelAoldnew


version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10, cl(gwno)
;
#delimit cr
estimates store modelAoldnew10


*------------------------------------------------------------------------------*
* Model B
*------------------------------------------------------------------------------*

version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst       
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   acd_maxduration
		   acd_cw
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5, cl(gwno)
;
#delimit cr
estimates store modelBoldnew


version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count
		   pgm_new_postconf_count
		   xconst       
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   acd_maxduration
		   acd_cw
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10, cl(gwno)
;
#delimit cr
estimates store modelBoldnew10




*------------------------------------------------------------------------------*
* Model C
*------------------------------------------------------------------------------*

version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count 
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   ib4.acd_termination_type
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=5, cl(gwno)
;
#delimit cr
estimates store modelColdnew



version 14
#delimit ;
ologit 	   pts_alt 
		   pgm_warlegacy_count 
		   pgm_new_postconf_count
		   xconst      
		   ptsL1_alt
		   media_free_lag
		   pko 
		   gov_change_L1
		   rgdppc_log
		   pop_log
		   ib4.acd_termination_type
		   peace_years 
		   peace_years2 
		   peace_years3
		   if peace_years<=10, cl(gwno)
;
#delimit cr
estimates store modelColdnew10




*------------------------------------------------------------------------------*
* Export results in table 
*------------------------------------------------------------------------------*

#delimit;													
esttab 	modelAoldnew modelBoldnew modelColdnew
        modelAoldnew10 modelBoldnew10 modelColdnew10 
using "Tables/cg_robustness_rebelvictory.tex", replace 
b(3) se(3) 
order( 			  pgm_warlegacy_count
				  pgm_new_postconf_count
				  acd_maxduration 
				  acd_cw
				  2.acd_termination_type 
				  3.acd_termination_type 
				  1.acd_termination_type 	
				  pko
				  xconst
				  gov_change_L1
				  ptsL1_alt
				  media_free_lag 
				  rgdppc_log
				  pop_log 	  
				  peace_years 
				  peace_years2 
				  peace_years3
				  _cons
				  ) 
nobaselevels 
stats(chi2 aic N_clust N, star(chi2) fmt(2 2 0 0) 
labels("Wald $\chi^{2}$""AIC""Number of clusters""Number of observations")) 
coeflabels( pgm_warlegacy_count    "PGM inherited from conflict\$\_{count}\$"
			pgm_new_postconf_count "PGM new to post-conflict\$\_{count}\$"
			xconst               "Executive constraints" 
			gov_change_L1 		 "Government change\$\_{lag}\$" 
			ptsL1_alt 	     	 "Physical integrity rights violations\$\_{lag}\$"
			media_free_lag 		 "Free media\$\_{lag}\$"
			pko              	 "PKO\$\_{presence}\$"
			pop_log      		 "Population\$\_{log}\$"
			rgdppc_log   		 "GDP\$\_{log}\$"
			2.acd_termination_type "Gov. victory\$\_{termination}\$"
			3.acd_termination_type "Settlement\$\_{termination}\$"
			1.acd_termination_type "Rebel victory\$\_{termination}\$"
			acd_maxduration        "Civil war\$\_{duration}\$"  
			acd_cw 		 		"Civil war\$\_{intensity}\$"
			peace_years  		"Peace years" 
			peace_years2 		"Peace years\$\_{^2}\$" 
			peace_years3 		"Peace years\$\_{^3}\$" 
			cut1:_cons				"Cut 1"
			cut2:_cons				"Cut 2"
			) 
label 
star(\dag 0.10 * 0.05  ** 0.01) 
nonumber
nomtitles
eqlabels(,none)
nolegend 
nonotes 
booktabs 
alignment(D{.}{.}{-1}) 
compress
substitute(\_ _)
fragment
prehead(
\begin{table}[!ht]\centering
\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
		\caption{Order logit estimations for the level of human rights violations in post-conflict societies---including post-conflict episodes for which the preceding conflict ended with rebel victory\label{tab:models_rebelvictory_count}}
		\setlength{\tabcolsep}{0pt}
		\scalebox{.7}{		
		\begin{tabular}{l*{6}{D{.}{.}{-1}}}
		\hline \hline	
		\addlinespace
		& \multicolumn{6}{c}{\textit{Dependent variable}: Physical Integrity Rights Violations}\\ 
		\cmidrule(r{5pt}l{5pt}){2-7} 
        \addlinespace
		& \multicolumn{3}{c}{Short term} & \multicolumn{3}{c}{Medium term}\\
		& \multicolumn{3}{c}{[5 years post-conflict]} & \multicolumn{3}{c}{[10 years post-conflict]}\\
		\addlinespace
		)
		postfoot(
		\hline \hline
		\multicolumn{7}{l}{\footnotesize \textit{Note:} Values are coefficients with robust standard errors in parentheses, clustered on country.}\\
		\multicolumn{7}{l}{\footnotesize  $\dag$ p$<$0.1, * p$<$0.05, ** p$<$0.01 (two-tailed test).}\\
		\end{tabular}
		}
		\end{table}		
		);
#delimit cr


*------------------------------------------------------------------------------*
* End of do file
*------------------------------------------------------------------------------*


